==> gnome-games-2.25.92.tar.bz2: gnome-games-2.25.92/aisleriot/translatable_game_names.h <==
gchar *s = N_("Accordion")
gchar *s = N_("Agnes")
gchar *s = N_("Athena")
gchar *s = N_("Auld Lang Syne")
gchar *s = N_("Aunt Mary")
gchar *s = N_("Backbone")
gchar *s = N_("Bakers Dozen")
gchar *s = N_("Bakers Game")
gchar *s = N_("Beleaguered Castle")
gchar *s = N_("Block Ten")
gchar *s = N_("Bristol")
gchar *s = N_("Camelot")
gchar *s = N_("Canfield")
gchar *s = N_("Carpet")
gchar *s = N_("Chessboard")
gchar *s = N_("Clock")
gchar *s = N_("Cover")
gchar *s = N_("Cruel")
gchar *s = N_("Diamond Mine")
gchar *s = N_("Doublets")
gchar *s = N_("Eagle Wing")
gchar *s = N_("Easthaven")
gchar *s = N_("Eight Off")
gchar *s = N_("Elevator")
gchar *s = N_("Escalator")
gchar *s = N_("First Law")
gchar *s = N_("Fortress")
gchar *s = N_("Fortunes")
gchar *s = N_("Forty Thieves")
gchar *s = N_("Fourteen")
gchar *s = N_("Freecell")
gchar *s = N_("Gaps")
gchar *s = N_("Gay Gordons")
gchar *s = N_("Glenwood")
gchar *s = N_("Gold Mine")
gchar *s = N_("Golf")
gchar *s = N_("Gypsy")
gchar *s = N_("Helsinki")
gchar *s = N_("Hopscotch")
gchar *s = N_("Isabel")
gchar *s = N_("Jamestown")
gchar *s = N_("Jumbo")
gchar *s = N_("Kansas")
gchar *s = N_("King Albert")
gchar *s = N_("Kings Audience")
gchar *s = N_("Klondike")
gchar *s = N_("Klondike Three Decks")
gchar *s = N_("Labyrinth")
gchar *s = N_("Lady Jane")
gchar *s = N_("Maze")
gchar *s = N_("Monte Carlo")
gchar *s = N_("Napoleons Tomb")
gchar *s = N_("Neighbor")
gchar *s = N_("Odessa")
gchar *s = N_("Osmosis")
gchar *s = N_("Peek")
gchar *s = N_("Pileon")
gchar *s = N_("Plait")
gchar *s = N_("Poker")
gchar *s = N_("Quatorze")
gchar *s = N_("Royal East")
gchar *s = N_("Saratoga")
gchar *s = N_("Scorpion")
gchar *s = N_("Scuffle")
gchar *s = N_("Seahaven")
gchar *s = N_("Sir Tommy")
gchar *s = N_("Spider")
gchar *s = N_("Spiderette")
gchar *s = N_("Spider Three Decks")
gchar *s = N_("Straight Up")
gchar *s = N_("Streets And Alleys")
gchar *s = N_("Template")
gchar *s = N_("Ten Across")
gchar *s = N_("Terrace")
gchar *s = N_("Thieves")
gchar *s = N_("Thirteen")
gchar *s = N_("Thumb And Pouch")
gchar *s = N_("Treize")
gchar *s = N_("Triple Peaks")
gchar *s = N_("Union Square")
gchar *s = N_("Valentine")
gchar *s = N_("Westhaven")
gchar *s = N_("Whitehead")
gchar *s = N_("Will O The Wisp")
gchar *s = N_("Yield")
gchar *s = N_("Yukon")
gchar *s = N_("Zebra")

==> gnome-games-2.27.2.tar.bz2: gnome-games-2.27.2/aisleriot/translatable_game_names.h <==
gchar *s = N_("Accordion")
gchar *s = N_("Agnes")
gchar *s = N_("Athena")
gchar *s = N_("Auld Lang Syne")
gchar *s = N_("Aunt Mary")
gchar *s = N_("Backbone")
gchar *s = N_("Bakers Dozen")
gchar *s = N_("Bakers Game")
gchar *s = N_("Bear River")
gchar *s = N_("Beleaguered Castle")
gchar *s = N_("Block Ten")
gchar *s = N_("Bristol")
gchar *s = N_("Camelot")
gchar *s = N_("Canfield")
gchar *s = N_("Carpet")
gchar *s = N_("Chessboard")
gchar *s = N_("Clock")
gchar *s = N_("Cover")
gchar *s = N_("Cruel")
gchar *s = N_("Diamond Mine")
gchar *s = N_("Doublets")
gchar *s = N_("Eagle Wing")
gchar *s = N_("Easthaven")
gchar *s = N_("Eight Off")
gchar *s = N_("Elevator")
gchar *s = N_("Escalator")
gchar *s = N_("First Law")
gchar *s = N_("Fortress")
gchar *s = N_("Fortunes")
gchar *s = N_("Forty Thieves")
gchar *s = N_("Fourteen")
gchar *s = N_("Freecell")
gchar *s = N_("Gaps")
gchar *s = N_("Gay Gordons")
gchar *s = N_("Giant")
gchar *s = N_("Glenwood")
gchar *s = N_("Gold Mine")
gchar *s = N_("Golf")
gchar *s = N_("Gypsy")
gchar *s = N_("Helsinki")
gchar *s = N_("Hopscotch")
gchar *s = N_("Isabel")
gchar *s = N_("Jamestown")
gchar *s = N_("Jumbo")
gchar *s = N_("Kansas")
gchar *s = N_("King Albert")
gchar *s = N_("Kings Audience")
gchar *s = N_("Klondike")
gchar *s = N_("Labyrinth")
gchar *s = N_("Lady Jane")
gchar *s = N_("Maze")
gchar *s = N_("Monte Carlo")
gchar *s = N_("Napoleons Tomb")
gchar *s = N_("Neighbor")
gchar *s = N_("Odessa")
gchar *s = N_("Osmosis")
gchar *s = N_("Peek")
gchar *s = N_("Pileon")
gchar *s = N_("Plait")
gchar *s = N_("Poker")
gchar *s = N_("Quatorze")
gchar *s = N_("Royal East")
gchar *s = N_("Saratoga")
gchar *s = N_("Scorpion")
gchar *s = N_("Scuffle")
gchar *s = N_("Seahaven")
gchar *s = N_("Sir Tommy")
gchar *s = N_("Spider")
gchar *s = N_("Spiderette")
gchar *s = N_("Spider Three Decks")
gchar *s = N_("Straight Up")
gchar *s = N_("Streets And Alleys")
gchar *s = N_("Template")
gchar *s = N_("Ten Across")
gchar *s = N_("Terrace")
gchar *s = N_("Thieves")
gchar *s = N_("Thirteen")
gchar *s = N_("Thumb And Pouch")
gchar *s = N_("Treize")
gchar *s = N_("Triple Peaks")
gchar *s = N_("Union Square")
gchar *s = N_("Valentine")
gchar *s = N_("Westhaven")
gchar *s = N_("Whitehead")
gchar *s = N_("Will O The Wisp")
gchar *s = N_("Yield")
gchar *s = N_("Yukon")
gchar *s = N_("Zebra")
